==> haskell-lsp-types-1.6.0.1-15-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lsp-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lsp-types
version:              1.6.0.1
visibility:           public
id:                   lsp-types-1.6.0.1-4hY9RFfJwow5nUnstGc4jR
key:                  lsp-types-1.6.0.1-4hY9RFfJwow5nUnstGc4jR
license:              MIT
copyright:            Alan Zimmerman, 2016-2021
maintainer:           alan.zimm@gmail.com
author:               Alan Zimmerman
homepage:             https://github.com/haskell/lsp
synopsis:
    Haskell library for the Microsoft Language Server Protocol, data types

description:
    An implementation of the types to allow language implementors to
    support the Language Server Protocol for their specific language.

category:             Development
abi:                  f4f9b83312096cf891a5247ea40a2332
exposed:              True
exposed-modules:
    Data.IxMap Language.LSP.Types Language.LSP.Types.Capabilities
    Language.LSP.Types.Lens Language.LSP.Types.SMethodMap

hidden-modules:
    Language.LSP.Types.CallHierarchy Language.LSP.Types.Cancellation
    Language.LSP.Types.ClientCapabilities Language.LSP.Types.CodeAction
    Language.LSP.Types.CodeLens Language.LSP.Types.Command
    Language.LSP.Types.Common Language.LSP.Types.Completion
    Language.LSP.Types.Configuration Language.LSP.Types.Declaration
    Language.LSP.Types.Definition Language.LSP.Types.Diagnostic
    Language.LSP.Types.DocumentColor Language.LSP.Types.DocumentFilter
    Language.LSP.Types.DocumentHighlight
    Language.LSP.Types.DocumentLink Language.LSP.Types.DocumentSymbol
    Language.LSP.Types.FoldingRange Language.LSP.Types.Formatting
    Language.LSP.Types.Hover Language.LSP.Types.Implementation
    Language.LSP.Types.Initialize Language.LSP.Types.Location
    Language.LSP.Types.LspId Language.LSP.Types.MarkupContent
    Language.LSP.Types.Method Language.LSP.Types.Message
    Language.LSP.Types.Parsing Language.LSP.Types.Progress
    Language.LSP.Types.Registration Language.LSP.Types.References
    Language.LSP.Types.Rename Language.LSP.Types.SelectionRange
    Language.LSP.Types.ServerCapabilities
    Language.LSP.Types.SemanticTokens Language.LSP.Types.SignatureHelp
    Language.LSP.Types.StaticRegistrationOptions
    Language.LSP.Types.TextDocument Language.LSP.Types.TypeDefinition
    Language.LSP.Types.Uri Language.LSP.Types.Utils
    Language.LSP.Types.Window Language.LSP.Types.WatchedFiles
    Language.LSP.Types.WorkspaceEdit
    Language.LSP.Types.WorkspaceFolders
    Language.LSP.Types.WorkspaceSymbol Language.LSP.Types.Uri.OsPath

import-dirs:          /usr/lib/ghc-9.4.8/site-local/lsp-types-1.6.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/lsp-types-1.6.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/lsp-types-1.6.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lsp-types
hs-libraries:         HSlsp-types-1.6.0.1-4hY9RFfJwow5nUnstGc4jR
depends:
    Diff-0.4.1-BOxCLpHEbnv464iV7Wt9tY
    aeson-2.1.2.1-3xjz2RyG2JVHhJgBzFxi7A base-4.17.2.1 binary-0.8.9.1
    containers-0.6.7 data-default-0.7.1.1-HuI8bY4bNR4F11jcRg6vOi
    deepseq-1.4.8.0 dlist-1.0-I6FB5Nlk17hG16fxQzZSEb exceptions-0.10.5
    filepath-1.4.2.2 hashable-1.4.4.0-3P57kjJkCag7O0bwYoaxX1
    lens-5.2.3-9tvnz3pLdcPH5JzlkQxTXA
    mod-0.2.0.1-JvH09iwquLIF8bzzw0qXw4 mtl-2.2.2
    network-uri-2.6.4.2-2U8duEjYT0p2SuyLAFgLE2
    safe-0.3.21-3UD7yhjS9NI84sQQ1YTdQf
    scientific-0.3.7.0-LKd2L2qVPICBdMYOyCcex4
    some-1.0.5-36xIADGNqiWGv9lC459cQD template-haskell-2.19.0.0
    text-2.0.2 unordered-containers-0.2.20-4cFR6FXPxn69oePlCyMUKW

haddock-interfaces:   /usr/share/doc/haskell-lsp-types/html/lsp-types.haddock
haddock-html:         /usr/share/doc/haskell-lsp-types/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-lsp-types-1.6.0.1-16-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lsp-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lsp-types
version:              1.6.0.1
visibility:           public
id:                   lsp-types-1.6.0.1-7l6k7efB4A64H0TlEBBUmw
key:                  lsp-types-1.6.0.1-7l6k7efB4A64H0TlEBBUmw
license:              MIT
copyright:            Alan Zimmerman, 2016-2021
maintainer:           alan.zimm@gmail.com
author:               Alan Zimmerman
homepage:             https://github.com/haskell/lsp
synopsis:
    Haskell library for the Microsoft Language Server Protocol, data types

description:
    An implementation of the types to allow language implementors to
    support the Language Server Protocol for their specific language.

category:             Development
abi:                  6fe1128e67ff50ac6d0f6cfda9d3a57a
exposed:              True
exposed-modules:
    Data.IxMap Language.LSP.Types Language.LSP.Types.Capabilities
    Language.LSP.Types.Lens Language.LSP.Types.SMethodMap

hidden-modules:
    Language.LSP.Types.CallHierarchy Language.LSP.Types.Cancellation
    Language.LSP.Types.ClientCapabilities Language.LSP.Types.CodeAction
    Language.LSP.Types.CodeLens Language.LSP.Types.Command
    Language.LSP.Types.Common Language.LSP.Types.Completion
    Language.LSP.Types.Configuration Language.LSP.Types.Declaration
    Language.LSP.Types.Definition Language.LSP.Types.Diagnostic
    Language.LSP.Types.DocumentColor Language.LSP.Types.DocumentFilter
    Language.LSP.Types.DocumentHighlight
    Language.LSP.Types.DocumentLink Language.LSP.Types.DocumentSymbol
    Language.LSP.Types.FoldingRange Language.LSP.Types.Formatting
    Language.LSP.Types.Hover Language.LSP.Types.Implementation
    Language.LSP.Types.Initialize Language.LSP.Types.Location
    Language.LSP.Types.LspId Language.LSP.Types.MarkupContent
    Language.LSP.Types.Method Language.LSP.Types.Message
    Language.LSP.Types.Parsing Language.LSP.Types.Progress
    Language.LSP.Types.Registration Language.LSP.Types.References
    Language.LSP.Types.Rename Language.LSP.Types.SelectionRange
    Language.LSP.Types.ServerCapabilities
    Language.LSP.Types.SemanticTokens Language.LSP.Types.SignatureHelp
    Language.LSP.Types.StaticRegistrationOptions
    Language.LSP.Types.TextDocument Language.LSP.Types.TypeDefinition
    Language.LSP.Types.Uri Language.LSP.Types.Utils
    Language.LSP.Types.Window Language.LSP.Types.WatchedFiles
    Language.LSP.Types.WorkspaceEdit
    Language.LSP.Types.WorkspaceFolders
    Language.LSP.Types.WorkspaceSymbol Language.LSP.Types.Uri.OsPath

import-dirs:          /usr/lib/ghc-9.4.8/site-local/lsp-types-1.6.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/lsp-types-1.6.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/lsp-types-1.6.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lsp-types
hs-libraries:         HSlsp-types-1.6.0.1-7l6k7efB4A64H0TlEBBUmw
depends:
    Diff-0.4.1-BOxCLpHEbnv464iV7Wt9tY
    aeson-2.1.2.1-25ntyCXNIMdHgIjcbgcdOM base-4.17.2.1 binary-0.8.9.1
    containers-0.6.7 data-default-0.7.1.1-HuI8bY4bNR4F11jcRg6vOi
    deepseq-1.4.8.0 dlist-1.0-I6FB5Nlk17hG16fxQzZSEb exceptions-0.10.5
    filepath-1.4.2.2 hashable-1.4.4.0-3P57kjJkCag7O0bwYoaxX1
    lens-5.2.3-9B9P7XM4qGB6Xd7Di9aRFA
    mod-0.2.0.1-C4W7fTgEwRiEMmNSr4RbdJ mtl-2.2.2
    network-uri-2.6.4.2-2U8duEjYT0p2SuyLAFgLE2
    safe-0.3.21-3UD7yhjS9NI84sQQ1YTdQf
    scientific-0.3.7.0-LKd2L2qVPICBdMYOyCcex4
    some-1.0.5-36xIADGNqiWGv9lC459cQD template-haskell-2.19.0.0
    text-2.0.2 unordered-containers-0.2.20-2oScjwZejU42oDENjBi2vG

haddock-interfaces:   /usr/share/doc/haskell-lsp-types/html/lsp-types.haddock
haddock-html:         /usr/share/doc/haskell-lsp-types/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
